# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.capacity.v1``"""

import builtins as builtins
import collections.abc as abc
import datetime as datetime
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import google.protobuf.timestamp_pb2 as timestamp_pb2
import nebius.aio.client as client
import nebius.aio.request as request
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.capacity.v1.capacity_block_group_pb2 as capacity_block_group_pb2
import nebius.api.nebius.capacity.v1.capacity_block_group_service_pb2 as capacity_block_group_service_pb2
import nebius.api.nebius.capacity.v1.capacity_interval_pb2 as capacity_interval_pb2
import nebius.api.nebius.capacity.v1.capacity_interval_service_pb2 as capacity_interval_service_pb2
import nebius.api.nebius.capacity.v1.resource_affinity_pb2 as resource_affinity_pb2
import nebius.api.nebius.common.v1 as v1_1
import nebius.api.nebius.common.v1.metadata_pb2 as metadata_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import nebius.base.protos.well_known as well_known_1
import typing as typing
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/capacity/v1/resource_affinity.proto
class ResourceAffinityComputeV1(pb_classes.Message):
    """
    First version of Compute service resource affinity
    """
    
    __PB2_CLASS__ = resource_affinity_pb2.ResourceAffinityComputeV1
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ResourceAffinityComputeV1",resource_affinity_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        fabric: "builtins.str|None|unset.UnsetType" = unset.Unset,
        platform: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(fabric, unset.UnsetType):
            self.fabric = fabric
        if not isinstance(platform, unset.UnsetType):
            self.platform = platform
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "fabric",
            "platform",
        ]
    
    @builtins.property
    def fabric(self) -> "builtins.str":
        """
        The fabric where the Capacity Block Group is allocated.
        """
        
        return super()._get_field("fabric", explicit_presence=False,
        )
    @fabric.setter
    def fabric(self, value: "builtins.str|None") -> None:
        return super()._set_field("fabric",value,explicit_presence=False,
        )
    
    @builtins.property
    def platform(self) -> "builtins.str":
        """
        The platform for which the Capacity Block Group is allocated.
        """
        
        return super()._get_field("platform", explicit_presence=False,
        )
    @platform.setter
    def platform(self, value: "builtins.str|None") -> None:
        return super()._set_field("platform",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "fabric":"fabric",
        "platform":"platform",
    }
    
class ResourceAffinity(pb_classes.Message):
    """
    Specification of the Capacity Block Group.
    """
    
    __PB2_CLASS__ = resource_affinity_pb2.ResourceAffinity
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ResourceAffinity",resource_affinity_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_versions__(pb_classes.OneOf):
        name: builtins.str= "versions"
        
        def __init__(self, msg: "ResourceAffinity") -> None:
            super().__init__()
            self._message: "ResourceAffinity" = msg
    
    class __OneOfClass_versions_compute_v1__(__OneOfClass_versions__):
        field: typing.Literal["compute_v1"] = "compute_v1"
        
        def __init__(self, msg: "ResourceAffinity") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "ResourceAffinityComputeV1":
            return self._message.compute_v1
    
    @builtins.property
    def versions(self) -> __OneOfClass_versions_compute_v1__|None:
        field_name_1: str|None = super().which_field_in_oneof("versions")
        match field_name_1:
            case "compute_v1":
                return self.__OneOfClass_versions_compute_v1__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        compute_v1: "ResourceAffinityComputeV1|resource_affinity_pb2.ResourceAffinityComputeV1|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(compute_v1, unset.UnsetType):
            self.compute_v1 = compute_v1
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "compute_v1",
            "versions",
        ]
    
    @builtins.property
    def compute_v1(self) -> "ResourceAffinityComputeV1|None":
        """
        First version of the compute Resource Affinity.
        """
        
        return super()._get_field("compute_v1", explicit_presence=True,
        wrap=ResourceAffinityComputeV1,
        )
    @compute_v1.setter
    def compute_v1(self, value: "ResourceAffinityComputeV1|resource_affinity_pb2.ResourceAffinityComputeV1|None") -> None:
        return super()._set_field("compute_v1",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "compute_v1":"compute_v1",
        "versions":"versions",
    }
    
# file: nebius/capacity/v1/capacity_block_group.proto
class CapacityBlockGroupSpec(pb_classes.Message):
    """
    Capacity Block Group specification.
    """
    
    __PB2_CLASS__ = capacity_block_group_pb2.CapacityBlockGroupSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityBlockGroupSpec",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
    ) -> None:
        super().__init__(initial_message)
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
        ]
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
    }
    
class CurrentContinuousInterval(pb_classes.Message):
    """
    Current, last or future concatenation of Capacity Intervals in a Capacity Block Group.
    """
    
    __PB2_CLASS__ = capacity_block_group_pb2.CurrentContinuousInterval
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CurrentContinuousInterval",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "start_time": well_known_1.ts_mask,
        "end_time": well_known_1.ts_mask,
    }
    
    class State(pb_enum.Enum):
        """
        Shows a state of a Continuous Interval.
        """
        
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.capacity.v1.CurrentContinuousInterval.State",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        STATE_UNSPECIFIED = 0
        """
        Shouldn't happen.
        """
        
        STATE_SCHEDULED = 1
        """
        Continuous Interval is in the future.
        """
        
        STATE_ACTIVE = 2
        """
        Continuous Interval is active.
        """
        
        STATE_EXPIRED = 3
        """
        Continuous Interval is in the past.
        """
        
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        start_time: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        end_time: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        quantity: "builtins.int|None|unset.UnsetType" = unset.Unset,
        state: "CurrentContinuousInterval.State|capacity_block_group_pb2.CurrentContinuousInterval.State|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(start_time, unset.UnsetType):
            self.start_time = start_time
        if not isinstance(end_time, unset.UnsetType):
            self.end_time = end_time
        if not isinstance(quantity, unset.UnsetType):
            self.quantity = quantity
        if not isinstance(state, unset.UnsetType):
            self.state = state
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "start_time",
            "end_time",
            "quantity",
            "state",
            "State",
        ]
    
    @builtins.property
    def start_time(self) -> "datetime.datetime":
        """
        Start time of the first interval(s) in Continuous Interval.
        """
        
        return super()._get_field("start_time", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @start_time.setter
    def start_time(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("start_time",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def end_time(self) -> "datetime.datetime":
        """
        End time of the last interval(s) in Continuous Interval.
        """
        
        return super()._get_field("end_time", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @end_time.setter
    def end_time(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("end_time",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def quantity(self) -> "builtins.int":
        """
        Quota quantity that is currently set, was set or will be set in the Continuous Interval depending on it's
        start_time and end_time.
        If the Continuous Interval is currently active, quantity is the sum of quantities of the currently active
        non-zero intervals.
        If the Continuous Interval is in the past, quantity is the sum of quantities of the last non-zero active
        intervals.
        If the Continuous Interval is in the future, quantity is the sum of the quantities of the first scheduled
        non-zero active intervals.
        """
        
        return super()._get_field("quantity", explicit_presence=False,
        )
    @quantity.setter
    def quantity(self, value: "builtins.int|None") -> None:
        return super()._set_field("quantity",value,explicit_presence=False,
        )
    
    @builtins.property
    def state(self) -> "CurrentContinuousInterval.State":
        """
        Continuous Interval state.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=CurrentContinuousInterval.State,
        )
    @state.setter
    def state(self, value: "CurrentContinuousInterval.State|capacity_block_group_pb2.CurrentContinuousInterval.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "start_time":"start_time",
        "end_time":"end_time",
        "quantity":"quantity",
        "state":"state",
        "State":"State",
    }
    
class CapacityBlockGroupStatus(pb_classes.Message):
    """
    Capacity Block Group status.
    """
    
    __PB2_CLASS__ = capacity_block_group_pb2.CapacityBlockGroupStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityBlockGroupStatus",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "next_change_at": well_known_1.ts_mask,
    }
    
    class State(pb_enum.Enum):
        """
        Shows the state of a Capacity Block Group with respect to its quota.
        """
        
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.capacity.v1.CapacityBlockGroupStatus.State",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        STATE_UNSPECIFIED = 0
        """
        Shouldn't happen.
        """
        
        STATE_ALLOCATING = 1
        """
        Capacity Block Group quota is being allocated as one or more capacity intervals have started.
        """
        
        STATE_ACTIVE = 2
        """
        Capacity Block Group quota is already allocated and active as one or more capacity intervals are active.
        """
        
        STATE_SHUTTING = 3
        """
        Capacity Block Group is being shut down due to absence of active intervals at the time.
        """
        
        STATE_INACTIVE = 4
        """
        Capacity Block Group is inactive due to absence of active intervals at the time.
        """
        
    
    class UsageState(pb_enum.Enum):
        """
        Shows the usage state if a Capacity Block Group quota.
        """
        
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.capacity.v1.CapacityBlockGroupStatus.UsageState",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        USAGE_STATE_UNSPECIFIED = 0
        """
        Shouldn't happen.
        """
        
        USAGE_STATE_USED = 1
        """
        Capacity Block Group quota is actively in use.
        """
        
        USAGE_STATE_NOT_USED = 2
        """
        Capacity Block Group quota is not currently in use.
        """
        
        USAGE_STATE_UNKNOWN = 3
        """
        Capacity Block Group region is unreachable, the current usage is therefore unknown.
        Please, retry the request later.
        """
        
    
    class __OneOfClass__next_change_to__(pb_classes.OneOf):
        name: builtins.str= "_next_change_to"
        
        def __init__(self, msg: "CapacityBlockGroupStatus") -> None:
            super().__init__()
            self._message: "CapacityBlockGroupStatus" = msg
    
    class __OneOfClass__next_change_to_next_change_to__(__OneOfClass__next_change_to__):
        field: typing.Literal["next_change_to"] = "next_change_to"
        
        def __init__(self, msg: "CapacityBlockGroupStatus") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "builtins.int":
            return self._message.next_change_to
    
    @builtins.property
    def _next_change_to(self) -> __OneOfClass__next_change_to_next_change_to__|None:
        field_name_1: str|None = super().which_field_in_oneof("_next_change_to")
        match field_name_1:
            case "next_change_to":
                return self.__OneOfClass__next_change_to_next_change_to__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        region: "builtins.str|None|unset.UnsetType" = unset.Unset,
        resource_affinity: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None|unset.UnsetType" = unset.Unset,
        service: "builtins.str|None|unset.UnsetType" = unset.Unset,
        state: "CapacityBlockGroupStatus.State|capacity_block_group_pb2.CapacityBlockGroupStatus.State|None|unset.UnsetType" = unset.Unset,
        current_limit: "builtins.int|None|unset.UnsetType" = unset.Unset,
        usage: "builtins.int|None|unset.UnsetType" = unset.Unset,
        usage_percentage: "builtins.str|None|unset.UnsetType" = unset.Unset,
        next_change_at: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        next_change_to: "builtins.int|None|unset.UnsetType" = unset.Unset,
        current_continuous_interval: "CurrentContinuousInterval|capacity_block_group_pb2.CurrentContinuousInterval|None|unset.UnsetType" = unset.Unset,
        usage_state: "CapacityBlockGroupStatus.UsageState|capacity_block_group_pb2.CapacityBlockGroupStatus.UsageState|None|unset.UnsetType" = unset.Unset,
        reconciling: "builtins.bool|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(region, unset.UnsetType):
            self.region = region
        if not isinstance(resource_affinity, unset.UnsetType):
            self.resource_affinity = resource_affinity
        if not isinstance(service, unset.UnsetType):
            self.service = service
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(current_limit, unset.UnsetType):
            self.current_limit = current_limit
        if not isinstance(usage, unset.UnsetType):
            self.usage = usage
        if not isinstance(usage_percentage, unset.UnsetType):
            self.usage_percentage = usage_percentage
        if not isinstance(next_change_at, unset.UnsetType):
            self.next_change_at = next_change_at
        if not isinstance(next_change_to, unset.UnsetType):
            self.next_change_to = next_change_to
        if not isinstance(current_continuous_interval, unset.UnsetType):
            self.current_continuous_interval = current_continuous_interval
        if not isinstance(usage_state, unset.UnsetType):
            self.usage_state = usage_state
        if not isinstance(reconciling, unset.UnsetType):
            self.reconciling = reconciling
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "region",
            "resource_affinity",
            "service",
            "state",
            "current_limit",
            "usage",
            "usage_percentage",
            "next_change_at",
            "next_change_to",
            "current_continuous_interval",
            "usage_state",
            "reconciling",
            "_next_change_to",
            "State",
            "UsageState",
        ]
    
    @builtins.property
    def region(self) -> "builtins.str":
        """
        Name of the region where the Capacity Block Group is allocated.
        Example: "eu-north1".
        """
        
        return super()._get_field("region", explicit_presence=False,
        )
    @region.setter
    def region(self, value: "builtins.str|None") -> None:
        return super()._set_field("region",value,explicit_presence=False,
        )
    
    @builtins.property
    def resource_affinity(self) -> "ResourceAffinity":
        """
        Specification of the Capacity Block Group.
        """
        
        return super()._get_field("resource_affinity", explicit_presence=False,
        wrap=ResourceAffinity,
        )
    @resource_affinity.setter
    def resource_affinity(self, value: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None") -> None:
        return super()._set_field("resource_affinity",value,explicit_presence=False,
        )
    
    @builtins.property
    def service(self) -> "builtins.str":
        """
        Service for which the Capacity Block Group is allocated.
        """
        
        return super()._get_field("service", explicit_presence=False,
        )
    @service.setter
    def service(self, value: "builtins.str|None") -> None:
        return super()._set_field("service",value,explicit_presence=False,
        )
    
    @builtins.property
    def state(self) -> "CapacityBlockGroupStatus.State":
        """
        Capacity Block Group state with respect to quota allocation.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=CapacityBlockGroupStatus.State,
        )
    @state.setter
    def state(self, value: "CapacityBlockGroupStatus.State|capacity_block_group_pb2.CapacityBlockGroupStatus.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def current_limit(self) -> "builtins.int":
        """
        Capacity Block Group current quota limit.
        """
        
        return super()._get_field("current_limit", explicit_presence=False,
        )
    @current_limit.setter
    def current_limit(self, value: "builtins.int|None") -> None:
        return super()._set_field("current_limit",value,explicit_presence=False,
        )
    
    @builtins.property
    def usage(self) -> "builtins.int":
        """
        Capacity Block Group quota usage.
        """
        
        return super()._get_field("usage", explicit_presence=False,
        )
    @usage.setter
    def usage(self, value: "builtins.int|None") -> None:
        return super()._set_field("usage",value,explicit_presence=False,
        )
    
    @builtins.property
    def usage_percentage(self) -> "builtins.str":
        """
        Capacity Block Group quota usage percentage.
        """
        
        return super()._get_field("usage_percentage", explicit_presence=False,
        )
    @usage_percentage.setter
    def usage_percentage(self, value: "builtins.str|None") -> None:
        return super()._set_field("usage_percentage",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_change_at(self) -> "datetime.datetime":
        """
        Time of the next Capacity Block Group quota change.
        """
        
        return super()._get_field("next_change_at", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @next_change_at.setter
    def next_change_at(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("next_change_at",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def next_change_to(self) -> "builtins.int|None":
        """
        The next expected change of the Capacity Block Group quota limit.
        the quota limit change that is currently performed.
        """
        
        return super()._get_field("next_change_to", explicit_presence=True,
        )
    @next_change_to.setter
    def next_change_to(self, value: "builtins.int|None") -> None:
        return super()._set_field("next_change_to",value,explicit_presence=True,
        )
    
    @builtins.property
    def current_continuous_interval(self) -> "CurrentContinuousInterval":
        """
        Current concatenation of non-zero Capacity Intervals that overlap or follow each other without a break.
        If all Capacity Intervals are in the past, returns the last Continuous Interval.
        If all Capacity Intervals are in the future, returns the first Continuous Interval scheduled.
        """
        
        return super()._get_field("current_continuous_interval", explicit_presence=False,
        wrap=CurrentContinuousInterval,
        )
    @current_continuous_interval.setter
    def current_continuous_interval(self, value: "CurrentContinuousInterval|capacity_block_group_pb2.CurrentContinuousInterval|None") -> None:
        return super()._set_field("current_continuous_interval",value,explicit_presence=False,
        )
    
    @builtins.property
    def usage_state(self) -> "CapacityBlockGroupStatus.UsageState":
        """
        Capacity Block Group quota usage state.
        """
        
        return super()._get_field("usage_state", explicit_presence=False,
        wrap=CapacityBlockGroupStatus.UsageState,
        )
    @usage_state.setter
    def usage_state(self, value: "CapacityBlockGroupStatus.UsageState|capacity_block_group_pb2.CapacityBlockGroupStatus.UsageState|None") -> None:
        return super()._set_field("usage_state",value,explicit_presence=False,
        )
    
    @builtins.property
    def reconciling(self) -> "builtins.bool":
        """
        Shows that changes are in flight.
        """
        
        return super()._get_field("reconciling", explicit_presence=False,
        )
    @reconciling.setter
    def reconciling(self, value: "builtins.bool|None") -> None:
        return super()._set_field("reconciling",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "region":"region",
        "resource_affinity":"resource_affinity",
        "service":"service",
        "state":"state",
        "current_limit":"current_limit",
        "usage":"usage",
        "usage_percentage":"usage_percentage",
        "next_change_at":"next_change_at",
        "next_change_to":"next_change_to",
        "current_continuous_interval":"current_continuous_interval",
        "usage_state":"usage_state",
        "reconciling":"reconciling",
        "_next_change_to":"_next_change_to",
        "State":"State",
        "UsageState":"UsageState",
    }
    
class CapacityBlockGroup(pb_classes.Message):
    """
    Capacity Block Group is a parent resource for Capacity Intervals.
    """
    
    __PB2_CLASS__ = capacity_block_group_pb2.CapacityBlockGroup
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityBlockGroup",capacity_block_group_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "CapacityBlockGroupSpec|capacity_block_group_pb2.CapacityBlockGroupSpec|None|unset.UnsetType" = unset.Unset,
        status: "CapacityBlockGroupStatus|capacity_block_group_pb2.CapacityBlockGroupStatus|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
        if not isinstance(status, unset.UnsetType):
            self.status = status
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
            "status",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "CapacityBlockGroupSpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=CapacityBlockGroupSpec,
        )
    @spec.setter
    def spec(self, value: "CapacityBlockGroupSpec|capacity_block_group_pb2.CapacityBlockGroupSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "CapacityBlockGroupStatus":
        return super()._get_field("status", explicit_presence=False,
        wrap=CapacityBlockGroupStatus,
        )
    @status.setter
    def status(self, value: "CapacityBlockGroupStatus|capacity_block_group_pb2.CapacityBlockGroupStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
        "status":"status",
    }
    
# file: nebius/capacity/v1/capacity_block_group_service.proto
class GetCapacityBlockGroupRequest(pb_classes.Message):
    """
    Get a Capacity Block Group by its ID.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.GetCapacityBlockGroupRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.GetCapacityBlockGroupRequest",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the Capacity Block Group.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class GetCapacityBlockGroupByResourceAffinityRequest(pb_classes.Message):
    """
    Get a Capacity Block Group in a Tenant by its Resource Affinity.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.GetCapacityBlockGroupByResourceAffinityRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.GetCapacityBlockGroupByResourceAffinityRequest",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        region: "builtins.str|None|unset.UnsetType" = unset.Unset,
        resource_affinity: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(region, unset.UnsetType):
            self.region = region
        if not isinstance(resource_affinity, unset.UnsetType):
            self.resource_affinity = resource_affinity
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "region",
            "resource_affinity",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Tenant ID of the Capacity Block Group.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def region(self) -> "builtins.str":
        """
        Name of the region where the Capacity Block Group is allocated.
        Example: "eu-north1".
        """
        
        return super()._get_field("region", explicit_presence=False,
        )
    @region.setter
    def region(self, value: "builtins.str|None") -> None:
        return super()._set_field("region",value,explicit_presence=False,
        )
    
    @builtins.property
    def resource_affinity(self) -> "ResourceAffinity":
        """
        Specifications of the Capacity Block Group.
        """
        
        return super()._get_field("resource_affinity", explicit_presence=False,
        wrap=ResourceAffinity,
        )
    @resource_affinity.setter
    def resource_affinity(self, value: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None") -> None:
        return super()._set_field("resource_affinity",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "region":"region",
        "resource_affinity":"resource_affinity",
    }
    
class ListCapacityBlockGroupsRequest(pb_classes.Message):
    """
    List Capacity Block Groups by a Tenant ID.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.ListCapacityBlockGroupsRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityBlockGroupsRequest",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Tenant ID of the Capacity Block Group.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        """
        Page size. Must be between [1...200].
        Optional; if not specified, a reasonable default will be chosen by the service.
        """
        
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        """
        Listing continuation token. Pass an empty string to start listing from the first page.
        """
        
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
    }
    
class ListCapacityBlockGroupsResponse(pb_classes.Message):
    """
    All existing Capacity Block Groups in a Tenant.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.ListCapacityBlockGroupsResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityBlockGroupsResponse",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[CapacityBlockGroup]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[CapacityBlockGroup]":
        """
        List of Capacity Block Groups on this result page.
        """
        
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(CapacityBlockGroup,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[CapacityBlockGroup]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        """
        Listing continuation token for the next page of results.
        """
        
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    
class ListCapacityBlockGroupResourcesRequest(pb_classes.Message):
    """
    List reservations instances in a Capacity Block Group by its ID.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.ListCapacityBlockGroupResourcesRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityBlockGroupResourcesRequest",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of a Capacity Block Group.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListCapacityBlockGroupResourcesResponse(pb_classes.Message):
    """
    All VM instances' IDs that occupy the Capacity Block Group.
    """
    
    __PB2_CLASS__ = capacity_block_group_service_pb2.ListCapacityBlockGroupResourcesResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityBlockGroupResourcesResponse",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_ids: "abc.Iterable[builtins.str]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_ids, unset.UnsetType):
            self.resource_ids = resource_ids
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_ids",
        ]
    
    @builtins.property
    def resource_ids(self) -> "abc.MutableSequence[builtins.str]":
        """
        List of instances' IDs.
        """
        
        return super()._get_field("resource_ids", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @resource_ids.setter
    def resource_ids(self, value: "abc.Iterable[builtins.str]|None") -> None:
        return super()._set_field("resource_ids",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_ids":"resource_ids",
    }
    

class CapacityBlockGroupServiceClient(client.Client):
    """
    Capacity Block Group service provides read access to Capacity Block Groups resources.
    
    This class provides the client methods for the ``.nebius.capacity.v1.CapacityBlockGroupService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.capacity.v1.CapacityBlockGroupService",capacity_block_group_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.capacity.v1.CapacityBlockGroupService"
    
    def get(self,
        request: "GetCapacityBlockGroupRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["GetCapacityBlockGroupRequest","CapacityBlockGroup"]:
        """
        Get Capacity Block Group by its ID.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.GetCapacityBlockGroupRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.CapacityBlockGroup`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=capacity_block_group_pb2.CapacityBlockGroup,
            result_wrapper=pb_classes.simple_wrapper(CapacityBlockGroup),
            **kwargs,
        )
    
    def get_by_resource_affinity(self,
        request: "GetCapacityBlockGroupByResourceAffinityRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["GetCapacityBlockGroupByResourceAffinityRequest","CapacityBlockGroup"]:
        """
        Get Capacity Block Group by its specification.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.GetCapacityBlockGroupByResourceAffinityRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.CapacityBlockGroup`.
        """
        
        return super().request(
            method="GetByResourceAffinity",
            request=request,
            result_pb2_class=capacity_block_group_pb2.CapacityBlockGroup,
            result_wrapper=pb_classes.simple_wrapper(CapacityBlockGroup),
            **kwargs,
        )
    
    def list(self,
        request: "ListCapacityBlockGroupsRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["ListCapacityBlockGroupsRequest","ListCapacityBlockGroupsResponse"]:
        """
        List all Capacity Block Groups for the specified Tenant.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.ListCapacityBlockGroupsRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.ListCapacityBlockGroupsResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=capacity_block_group_service_pb2.ListCapacityBlockGroupsResponse,
            result_wrapper=pb_classes.simple_wrapper(ListCapacityBlockGroupsResponse),
            **kwargs,
        )
    
    def list_resources(self,
        request: "ListCapacityBlockGroupResourcesRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["ListCapacityBlockGroupResourcesRequest","ListCapacityBlockGroupResourcesResponse"]:
        """
        List virtual machines instances' IDs that occupy a Capacity Block Group by its ID.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.ListCapacityBlockGroupResourcesRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.ListCapacityBlockGroupResourcesResponse`.
        """
        
        return super().request(
            method="ListResources",
            request=request,
            result_pb2_class=capacity_block_group_service_pb2.ListCapacityBlockGroupResourcesResponse,
            result_wrapper=pb_classes.simple_wrapper(ListCapacityBlockGroupResourcesResponse),
            **kwargs,
        )
    

# file: nebius/capacity/v1/capacity_interval.proto
class CapacityIntervalSpec(pb_classes.Message):
    """
    Capacity Interval specification.
    """
    
    __PB2_CLASS__ = capacity_interval_pb2.CapacityIntervalSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityIntervalSpec",capacity_interval_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
    ) -> None:
        super().__init__(initial_message)
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
        ]
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
    }
    
class CapacityIntervalStatus(pb_classes.Message):
    """
    Capacity Interval status data.
    """
    
    __PB2_CLASS__ = capacity_interval_pb2.CapacityIntervalStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityIntervalStatus",capacity_interval_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "start_time": well_known_1.ts_mask,
        "end_time": well_known_1.ts_mask,
    }
    
    class State(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.capacity.v1.CapacityIntervalStatus.State",capacity_interval_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        STATE_UNSPECIFIED = 0
        """
        Shouldn't happen.
        """
        
        STATE_SCHEDULED = 1
        """
        Capacity Interval is fully in the future (now < start_time).
        """
        
        STATE_ACTIVE = 2
        """
        Capacity Interval is currently active (start_time <= now < end_time).
        """
        
        STATE_EXPIRED = 3
        """
        Capacity Interval is fully in the past (end_time <= now).
        """
        
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        container_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        region: "builtins.str|None|unset.UnsetType" = unset.Unset,
        resource_affinity: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None|unset.UnsetType" = unset.Unset,
        service: "builtins.str|None|unset.UnsetType" = unset.Unset,
        quantity: "builtins.int|None|unset.UnsetType" = unset.Unset,
        start_time: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        end_time: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        state: "CapacityIntervalStatus.State|capacity_interval_pb2.CapacityIntervalStatus.State|None|unset.UnsetType" = unset.Unset,
        reconciling: "builtins.bool|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(container_id, unset.UnsetType):
            self.container_id = container_id
        if not isinstance(region, unset.UnsetType):
            self.region = region
        if not isinstance(resource_affinity, unset.UnsetType):
            self.resource_affinity = resource_affinity
        if not isinstance(service, unset.UnsetType):
            self.service = service
        if not isinstance(quantity, unset.UnsetType):
            self.quantity = quantity
        if not isinstance(start_time, unset.UnsetType):
            self.start_time = start_time
        if not isinstance(end_time, unset.UnsetType):
            self.end_time = end_time
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(reconciling, unset.UnsetType):
            self.reconciling = reconciling
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "container_id",
            "region",
            "resource_affinity",
            "service",
            "quantity",
            "start_time",
            "end_time",
            "state",
            "reconciling",
            "State",
        ]
    
    @builtins.property
    def container_id(self) -> "builtins.str":
        """
        Tenant ID for which the Capacity Interval is created.
        """
        
        return super()._get_field("container_id", explicit_presence=False,
        )
    @container_id.setter
    def container_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("container_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def region(self) -> "builtins.str":
        """
        Name of the region where the Capacity Interval is created.
        Example: "eu-north1".
        """
        
        return super()._get_field("region", explicit_presence=False,
        )
    @region.setter
    def region(self, value: "builtins.str|None") -> None:
        return super()._set_field("region",value,explicit_presence=False,
        )
    
    @builtins.property
    def resource_affinity(self) -> "ResourceAffinity":
        """
        Specification of the Capacity Interval.
        """
        
        return super()._get_field("resource_affinity", explicit_presence=False,
        wrap=ResourceAffinity,
        )
    @resource_affinity.setter
    def resource_affinity(self, value: "ResourceAffinity|resource_affinity_pb2.ResourceAffinity|None") -> None:
        return super()._set_field("resource_affinity",value,explicit_presence=False,
        )
    
    @builtins.property
    def service(self) -> "builtins.str":
        """
        Service for which the Capacity Interval is created.
        """
        
        return super()._get_field("service", explicit_presence=False,
        )
    @service.setter
    def service(self, value: "builtins.str|None") -> None:
        return super()._set_field("service",value,explicit_presence=False,
        )
    
    @builtins.property
    def quantity(self) -> "builtins.int":
        """
        Resource quantity of the Capacity Interval.
        """
        
        return super()._get_field("quantity", explicit_presence=False,
        )
    @quantity.setter
    def quantity(self, value: "builtins.int|None") -> None:
        return super()._set_field("quantity",value,explicit_presence=False,
        )
    
    @builtins.property
    def start_time(self) -> "datetime.datetime":
        """
        Start time of the Capacity Interval.
        """
        
        return super()._get_field("start_time", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @start_time.setter
    def start_time(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("start_time",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def end_time(self) -> "datetime.datetime":
        """
        End time of the Capacity Interval.
        """
        
        return super()._get_field("end_time", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @end_time.setter
    def end_time(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("end_time",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def state(self) -> "CapacityIntervalStatus.State":
        """
        State of the Capacity Interval.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=CapacityIntervalStatus.State,
        )
    @state.setter
    def state(self, value: "CapacityIntervalStatus.State|capacity_interval_pb2.CapacityIntervalStatus.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def reconciling(self) -> "builtins.bool":
        """
        Shows that changes are in flight.
        """
        
        return super()._get_field("reconciling", explicit_presence=False,
        )
    @reconciling.setter
    def reconciling(self, value: "builtins.bool|None") -> None:
        return super()._set_field("reconciling",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "container_id":"container_id",
        "region":"region",
        "resource_affinity":"resource_affinity",
        "service":"service",
        "quantity":"quantity",
        "start_time":"start_time",
        "end_time":"end_time",
        "state":"state",
        "reconciling":"reconciling",
        "State":"State",
    }
    
class CapacityInterval(pb_classes.Message):
    """
    Capacity Intervals represents a timeframe during which the specified resources can be used.
    """
    
    __PB2_CLASS__ = capacity_interval_pb2.CapacityInterval
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.CapacityInterval",capacity_interval_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "CapacityIntervalSpec|capacity_interval_pb2.CapacityIntervalSpec|None|unset.UnsetType" = unset.Unset,
        status: "CapacityIntervalStatus|capacity_interval_pb2.CapacityIntervalStatus|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
        if not isinstance(status, unset.UnsetType):
            self.status = status
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
            "status",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "CapacityIntervalSpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=CapacityIntervalSpec,
        )
    @spec.setter
    def spec(self, value: "CapacityIntervalSpec|capacity_interval_pb2.CapacityIntervalSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "CapacityIntervalStatus":
        return super()._get_field("status", explicit_presence=False,
        wrap=CapacityIntervalStatus,
        )
    @status.setter
    def status(self, value: "CapacityIntervalStatus|capacity_interval_pb2.CapacityIntervalStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
        "status":"status",
    }
    
# file: nebius/capacity/v1/capacity_interval_service.proto
class GetCapacityIntervalRequest(pb_classes.Message):
    """
    Getting Capacity Interval by its ID.
    """
    
    __PB2_CLASS__ = capacity_interval_service_pb2.GetCapacityIntervalRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.GetCapacityIntervalRequest",capacity_interval_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListCapacityIntervalsRequest(pb_classes.Message):
    """
    Listing all existing Capacity Intervals in a Capacity Block Group.
    """
    
    __PB2_CLASS__ = capacity_interval_service_pb2.ListCapacityIntervalsRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityIntervalsRequest",capacity_interval_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Capacity Block Group ID for which the Capacity Intervals should be listed.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        """
        Page size. Must be between [1...200].
        Optional; if not specified, a reasonable default will be chosen by the service.
        """
        
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        """
        Listing continuation token. Pass an empty string to start listing from the first page.
        """
        
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
    }
    
class ListCapacityIntervalsResponse(pb_classes.Message):
    """
    All existing Capacity Intervals in a Capacity Block Group.
    """
    
    __PB2_CLASS__ = capacity_interval_service_pb2.ListCapacityIntervalsResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.capacity.v1.ListCapacityIntervalsResponse",capacity_interval_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[CapacityInterval]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[CapacityInterval]":
        """
        List of Capacity Intervals on this result page.
        """
        
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(CapacityInterval,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[CapacityInterval]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        """
        Listing continuation token for the next page of results.
        """
        
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    

class CapacityIntervalServiceClient(client.Client):
    """
    Capacity Interval service provides read access to Capacity Intervals resources.
    
    This class provides the client methods for the ``.nebius.capacity.v1.CapacityIntervalService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.capacity.v1.CapacityIntervalService",capacity_interval_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.capacity.v1.CapacityIntervalService"
    
    def get(self,
        request: "GetCapacityIntervalRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["GetCapacityIntervalRequest","CapacityInterval"]:
        """
        Get Capacity Interval by its ID.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.GetCapacityIntervalRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.CapacityInterval`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=capacity_interval_pb2.CapacityInterval,
            result_wrapper=pb_classes.simple_wrapper(CapacityInterval),
            **kwargs,
        )
    
    def list(self,
        request: "ListCapacityIntervalsRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["ListCapacityIntervalsRequest","ListCapacityIntervalsResponse"]:
        """
        List all capacity intervals in a Capacity Block Group.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.capacity.v1.ListCapacityIntervalsRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.capacity.v1.ListCapacityIntervalsResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=capacity_interval_service_pb2.ListCapacityIntervalsResponse,
            result_wrapper=pb_classes.simple_wrapper(ListCapacityIntervalsResponse),
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "ResourceAffinityComputeV1",
    "ResourceAffinity",
    "CapacityBlockGroupSpec",
    "CurrentContinuousInterval",
    "CapacityBlockGroupStatus",
    "CapacityBlockGroup",
    "GetCapacityBlockGroupRequest",
    "GetCapacityBlockGroupByResourceAffinityRequest",
    "ListCapacityBlockGroupsRequest",
    "ListCapacityBlockGroupsResponse",
    "ListCapacityBlockGroupResourcesRequest",
    "ListCapacityBlockGroupResourcesResponse",
    "CapacityBlockGroupServiceClient",
    "CapacityIntervalSpec",
    "CapacityIntervalStatus",
    "CapacityInterval",
    "GetCapacityIntervalRequest",
    "ListCapacityIntervalsRequest",
    "ListCapacityIntervalsResponse",
    "CapacityIntervalServiceClient",
]



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.audit.v2 import audit_event_service_pb2 as _audit_event_service_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuditEventExportState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    AUDIT_EVENT_EXPORT_STATE_UNSPECIFIED: _ClassVar[AuditEventExportState]
    AUDIT_EVENT_EXPORT_STATE_RUNNING: _ClassVar[AuditEventExportState]
    AUDIT_EVENT_EXPORT_STATE_CANCELED: _ClassVar[AuditEventExportState]
    AUDIT_EVENT_EXPORT_STATE_DONE: _ClassVar[AuditEventExportState]
    AUDIT_EVENT_EXPORT_STATE_FAILED: _ClassVar[AuditEventExportState]
AUDIT_EVENT_EXPORT_STATE_UNSPECIFIED: AuditEventExportState
AUDIT_EVENT_EXPORT_STATE_RUNNING: AuditEventExportState
AUDIT_EVENT_EXPORT_STATE_CANCELED: AuditEventExportState
AUDIT_EVENT_EXPORT_STATE_DONE: AuditEventExportState
AUDIT_EVENT_EXPORT_STATE_FAILED: AuditEventExportState

class AuditEventExport(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: AuditEventExportSpec
    status: AuditEventExportStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[AuditEventExportSpec, _Mapping]] = ..., status: _Optional[_Union[AuditEventExportStatus, _Mapping]] = ...) -> None: ...

class AuditEventExportSpec(_message.Message):
    __slots__ = ["params", "nebius_object_storage"]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    NEBIUS_OBJECT_STORAGE_FIELD_NUMBER: _ClassVar[int]
    params: AuditEventExportParams
    nebius_object_storage: NebiusObjectStorageDestination
    def __init__(self, params: _Optional[_Union[AuditEventExportParams, _Mapping]] = ..., nebius_object_storage: _Optional[_Union[NebiusObjectStorageDestination, _Mapping]] = ...) -> None: ...

class NebiusObjectStorageDestination(_message.Message):
    __slots__ = ["object_prefix", "bucket_by_id"]
    OBJECT_PREFIX_FIELD_NUMBER: _ClassVar[int]
    BUCKET_BY_ID_FIELD_NUMBER: _ClassVar[int]
    object_prefix: str
    bucket_by_id: BucketById
    def __init__(self, object_prefix: _Optional[str] = ..., bucket_by_id: _Optional[_Union[BucketById, _Mapping]] = ...) -> None: ...

class BucketById(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class AuditEventExportParams(_message.Message):
    __slots__ = ["to", "filter", "event_type"]
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    to: _timestamp_pb2.Timestamp
    filter: str
    event_type: _audit_event_service_pb2.EventType
    def __init__(self, to: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., filter: _Optional[str] = ..., event_type: _Optional[_Union[_audit_event_service_pb2.EventType, str]] = ..., **kwargs) -> None: ...

class AuditEventExportStatus(_message.Message):
    __slots__ = ["state"]
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: AuditEventExportState
    def __init__(self, state: _Optional[_Union[AuditEventExportState, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event_export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.audit.v2 import audit_event_service_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__service__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/audit/v2/audit_event_export.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a)nebius/audit/v2/audit_event_service.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xce\x01\n\x10\x41uditEventExport\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.audit.v2.AuditEventExportSpecR\x04spec\x12?\n\x06status\x18\x03 \x01(\x0b\x32\'.nebius.audit.v2.AuditEventExportStatusR\x06status\"\xe3\x01\n\x14\x41uditEventExportSpec\x12G\n\x06params\x18\x01 \x01(\x0b\x32\'.nebius.audit.v2.AuditEventExportParamsB\x06\xbaH\x03\xc8\x01\x01R\x06params\x12\x65\n\x15nebius_object_storage\x18\x02 \x01(\x0b\x32/.nebius.audit.v2.NebiusObjectStorageDestinationH\x00R\x13nebiusObjectStorageB\x1b\n\x12\x65xport_destination\x12\x05\xbaH\x02\x08\x01\"\x97\x01\n\x1eNebiusObjectStorageDestination\x12#\n\robject_prefix\x18\x01 \x01(\tR\x0cobjectPrefix\x12?\n\x0c\x62ucket_by_id\x18\x02 \x01(\x0b\x32\x1b.nebius.audit.v2.BucketByIdH\x00R\nbucketByIdB\x0f\n\x06\x62ucket\x12\x05\xbaH\x02\x08\x01\"$\n\nBucketById\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xe4\x01\n\x16\x41uditEventExportParams\x12\x36\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x04\x66rom\x12\x32\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x02to\x12\x1b\n\x06\x66ilter\x18\x03 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\x12\x41\n\nevent_type\x18\x04 \x01(\x0e\x32\x1a.nebius.audit.v2.EventTypeB\x06\xbaH\x03\xc8\x01\x01R\teventType\"V\n\x16\x41uditEventExportStatus\x12<\n\x05state\x18\x01 \x01(\x0e\x32&.nebius.audit.v2.AuditEventExportStateR\x05state*\xd6\x01\n\x15\x41uditEventExportState\x12(\n$AUDIT_EVENT_EXPORT_STATE_UNSPECIFIED\x10\x00\x12$\n AUDIT_EVENT_EXPORT_STATE_RUNNING\x10\x01\x12%\n!AUDIT_EVENT_EXPORT_STATE_CANCELED\x10\x02\x12!\n\x1d\x41UDIT_EVENT_EXPORT_STATE_DONE\x10\x03\x12#\n\x1f\x41UDIT_EVENT_EXPORT_STATE_FAILED\x10\x04\x42`\n\x16\x61i.nebius.pub.audit.v2B\x15\x41uditEventExportProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_export_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\025AuditEventExportProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUDITEVENTEXPORTSPEC.oneofs_by_name['export_destination']._options = None
  _AUDITEVENTEXPORTSPEC.oneofs_by_name['export_destination']._serialized_options = b'\272H\002\010\001'
  _AUDITEVENTEXPORTSPEC.fields_by_name['params']._options = None
  _AUDITEVENTEXPORTSPEC.fields_by_name['params']._serialized_options = b'\272H\003\310\001\001'
  _NEBIUSOBJECTSTORAGEDESTINATION.oneofs_by_name['bucket']._options = None
  _NEBIUSOBJECTSTORAGEDESTINATION.oneofs_by_name['bucket']._serialized_options = b'\272H\002\010\001'
  _BUCKETBYID.fields_by_name['id']._options = None
  _BUCKETBYID.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['from']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['from']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['to']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['to']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['filter']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['filter']._serialized_options = b'\300J\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['event_type']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['event_type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUDITEVENTEXPORTSTATE']._serialized_start=1176
  _globals['_AUDITEVENTEXPORTSTATE']._serialized_end=1390
  _globals['_AUDITEVENTEXPORT']._serialized_start=226
  _globals['_AUDITEVENTEXPORT']._serialized_end=432
  _globals['_AUDITEVENTEXPORTSPEC']._serialized_start=435
  _globals['_AUDITEVENTEXPORTSPEC']._serialized_end=662
  _globals['_NEBIUSOBJECTSTORAGEDESTINATION']._serialized_start=665
  _globals['_NEBIUSOBJECTSTORAGEDESTINATION']._serialized_end=816
  _globals['_BUCKETBYID']._serialized_start=818
  _globals['_BUCKETBYID']._serialized_end=854
  _globals['_AUDITEVENTEXPORTPARAMS']._serialized_start=857
  _globals['_AUDITEVENTEXPORTPARAMS']._serialized_end=1085
  _globals['_AUDITEVENTEXPORTSTATUS']._serialized_start=1087
  _globals['_AUDITEVENTEXPORTSTATUS']._serialized_end=1173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/ai/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.compute.v1 import disk_pb2 as nebius_dot_compute_dot_v1_dot_disk__pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as nebius_dot_compute_dot_v1_dot_instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16nebius/ai/v1/job.proto\x12\x0cnebius.ai.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1cnebius/compute/v1/disk.proto\x1a nebius/compute/v1/instance.proto\"\xb7\x01\n\x03Job\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x15.nebius.ai.v1.JobSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x35\n\x06status\x18\x03 \x01(\x0b\x32\x17.nebius.ai.v1.JobStatusB\x04\xbaJ\x01\x05R\x06status\"\xb7\r\n\x07JobSpec\x12\x1c\n\x05image\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05image\x12^\n\x15\x65nvironment_variables\x18\x02 \x03(\x0b\x32).nebius.ai.v1.JobSpec.EnvironmentVariableR\x14\x65nvironmentVariables\x12\x30\n\x05ports\x18\x03 \x03(\x0b\x32\x1a.nebius.ai.v1.JobSpec.PortR\x05ports\x12+\n\x11\x63ontainer_command\x18\x04 \x01(\tR\x10\x63ontainerCommand\x12\x12\n\x04\x61rgs\x18\x05 \x01(\tR\x04\x61rgs\x12)\n\x0bworking_dir\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x01R\nworkingDir\x12;\n\x07volumes\x18\x07 \x03(\x0b\x32!.nebius.ai.v1.JobSpec.VolumeMountR\x07volumes\x12\\\n\x14registry_credentials\x18\n \x01(\x0b\x32).nebius.ai.v1.JobSpec.RegistryCredentialsR\x13registryCredentials\x12\"\n\x08platform\x18\x14 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x1e\n\x06preset\x18\x15 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06preset\x12-\n\x0eshm_size_bytes\x18\x16 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x0cshmSizeBytes\x12:\n\x04\x64isk\x18\x17 \x01(\x0b\x32\x1e.nebius.ai.v1.JobSpec.DiskSpecB\x06\xbaH\x03\xc8\x01\x01R\x04\x64isk\x12\x31\n\tsubnet_id\x18\x18 \x01(\tB\x14\xbaH\x03\xc8\x01\x01\xe2J\x0b\n\tvpcsubnetR\x08subnetId\x12\x1b\n\tpublic_ip\x18\x19 \x01(\x08R\x08publicIp\x12.\n\x13ssh_authorized_keys\x18\x1a \x03(\tR\x11sshAuthorizedKeys\x12;\n\x10restart_attempts\x18\x1e \x01(\x03\x42\x10\xbaH\r\"\x0b(\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01R\x0frestartAttempts\x12\x33\n\x07timeout\x18\x1f \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x1aL\n\x13\x45nvironmentVariable\x12\x1a\n\x04name\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12\x19\n\x05value\x18\x02 \x01(\tB\x03\xc0J\x01R\x05value\x1a\xef\x01\n\x04Port\x12\x32\n\x0e\x63ontainer_port\x18\x01 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\x01R\rcontainerPort\x12(\n\thost_port\x18\x02 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\x00R\x08hostPort\x12G\n\x08protocol\x18\x03 \x01(\x0e\x32#.nebius.ai.v1.JobSpec.Port.ProtocolB\x06\xbaH\x03\xc8\x01\x01R\x08protocol\"@\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\x07\n\x03TCP\x10\x02\x12\x07\n\x03UDP\x10\x03\x1a\x95\x02\n\x0bVolumeMount\x12=\n\x06source\x18\x01 \x01(\tB%\xe2J\"\n\x11\x63omputefilesystem\n\rstoragebucketR\x06source\x12\x1f\n\x0bsource_path\x18\x02 \x01(\tR\nsourcePath\x12%\n\x0e\x63ontainer_path\x18\x03 \x01(\tR\rcontainerPath\x12\x42\n\x04mode\x18\x04 \x01(\x0e\x32&.nebius.ai.v1.JobSpec.VolumeMount.ModeB\x06\xbaH\x03\xc8\x01\x01R\x04mode\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nREAD_WRITE\x10\x01\x12\r\n\tREAD_ONLY\x10\x02\x1ak\n\x08\x44iskSpec\x12@\n\x04type\x18\x01 \x01(\x0e\x32$.nebius.compute.v1.DiskSpec.DiskTypeB\x06\xbaH\x03\xc8\x01\x01R\x04type\x12\x1d\n\nsize_bytes\x18\x02 \x01(\x03R\tsizeBytes\x1a\x8e\x01\n\x13RegistryCredentials\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x1f\n\x08password\x18\x02 \x01(\tB\x03\xc0J\x01R\x08password\x12:\n\x19mysterybox_secret_version\x18\x03 \x01(\tR\x17mysteryboxSecretVersion\"\xbc\x03\n\tJobStatus\x12+\n\x11private_endpoints\x18\x01 \x03(\tR\x10privateEndpoints\x12)\n\x10public_endpoints\x18\x02 \x03(\tR\x0fpublicEndpoints\x12=\n\tinstances\x18\n \x03(\x0b\x32\x1f.nebius.ai.v1.JobInstanceStatusR\tinstances\x12\x33\n\x05state\x18\x14 \x01(\x0e\x32\x1d.nebius.ai.v1.JobStatus.StateR\x05state\x12\x42\n\rstate_details\x18\x15 \x01(\x0b\x32\x1d.nebius.ai.v1.JobStateDetailsR\x0cstateDetails\"\x9e\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0e\n\nCANCELLING\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\r\n\tCOMPLETED\x10\x06\x12\n\n\x06\x46\x41ILED\x10\x07\x12\r\n\tCANCELLED\x10\x08\x12\t\n\x05\x45RROR\x10\t\"G\n\x0fJobStateDetails\x12\x1a\n\x04\x63ode\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\xfa\x03\n\x11JobInstanceStatus\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32%.nebius.ai.v1.JobInstanceStatus.StateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12\x44\n\x13\x63ompute_instance_id\x18\n \x01(\tB\x14\xe2J\x11\n\x0f\x63omputeinstanceR\x11\x63omputeInstanceId\x12m\n\x16\x63ompute_instance_state\x18\x0b \x01(\x0e\x32/.nebius.compute.v1.InstanceStatus.InstanceStateB\x06\xbaH\x03\xc8\x01\x01R\x14\x63omputeInstanceState\x12\x1d\n\nprivate_ip\x18\x0c \x01(\tR\tprivateIp\x12\x1b\n\tpublic_ip\x18\r \x01(\tR\x08publicIp\"\xae\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0e\n\nCOMPLETING\x10\x04\x12\x0e\n\nCANCELLING\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\r\n\tCOMPLETED\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\r\n\tCANCELLED\x10\t\x12\t\n\x05\x45RROR\x10\nBM\n\x13\x61i.nebius.pub.ai.v1B\x08JobProtoP\x01Z*github.com/nebius/gosdk/proto/nebius/ai/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.ai.v1.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ai.nebius.pub.ai.v1B\010JobProtoP\001Z*github.com/nebius/gosdk/proto/nebius/ai/v1'
  _JOB.fields_by_name['metadata']._options = None
  _JOB.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _JOB.fields_by_name['spec']._options = None
  _JOB.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _JOB.fields_by_name['status']._options = None
  _JOB.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _JOBSPEC_ENVIRONMENTVARIABLE.fields_by_name['name']._options = None
  _JOBSPEC_ENVIRONMENTVARIABLE.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC_ENVIRONMENTVARIABLE.fields_by_name['value']._options = None
  _JOBSPEC_ENVIRONMENTVARIABLE.fields_by_name['value']._serialized_options = b'\300J\001'
  _JOBSPEC_PORT.fields_by_name['container_port']._options = None
  _JOBSPEC_PORT.fields_by_name['container_port']._serialized_options = b'\272H\010\032\006\030\377\377\003(\001'
  _JOBSPEC_PORT.fields_by_name['host_port']._options = None
  _JOBSPEC_PORT.fields_by_name['host_port']._serialized_options = b'\272H\010\032\006\030\377\377\003(\000'
  _JOBSPEC_PORT.fields_by_name['protocol']._options = None
  _JOBSPEC_PORT.fields_by_name['protocol']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC_VOLUMEMOUNT.fields_by_name['source']._options = None
  _JOBSPEC_VOLUMEMOUNT.fields_by_name['source']._serialized_options = b'\342J\"\n\021computefilesystem\n\rstoragebucket'
  _JOBSPEC_VOLUMEMOUNT.fields_by_name['mode']._options = None
  _JOBSPEC_VOLUMEMOUNT.fields_by_name['mode']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC_DISKSPEC.fields_by_name['type']._options = None
  _JOBSPEC_DISKSPEC.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC_REGISTRYCREDENTIALS.fields_by_name['password']._options = None
  _JOBSPEC_REGISTRYCREDENTIALS.fields_by_name['password']._serialized_options = b'\300J\001'
  _JOBSPEC.fields_by_name['image']._options = None
  _JOBSPEC.fields_by_name['image']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC.fields_by_name['working_dir']._options = None
  _JOBSPEC.fields_by_name['working_dir']._serialized_options = b'\272H\005r\003\030\200\001'
  _JOBSPEC.fields_by_name['platform']._options = None
  _JOBSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC.fields_by_name['preset']._options = None
  _JOBSPEC.fields_by_name['preset']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC.fields_by_name['shm_size_bytes']._options = None
  _JOBSPEC.fields_by_name['shm_size_bytes']._serialized_options = b'\272H\004\"\002(\000'
  _JOBSPEC.fields_by_name['disk']._options = None
  _JOBSPEC.fields_by_name['disk']._serialized_options = b'\272H\003\310\001\001'
  _JOBSPEC.fields_by_name['subnet_id']._options = None
  _JOBSPEC.fields_by_name['subnet_id']._serialized_options = b'\272H\003\310\001\001\342J\013\n\tvpcsubnet'
  _JOBSPEC.fields_by_name['restart_attempts']._options = None
  _JOBSPEC.fields_by_name['restart_attempts']._serialized_options = b'\272H\r\"\013(\377\377\377\377\377\377\377\377\377\001'
  _JOBSTATEDETAILS.fields_by_name['code']._options = None
  _JOBSTATEDETAILS.fields_by_name['code']._serialized_options = b'\272H\003\310\001\001'
  _JOBINSTANCESTATUS.fields_by_name['state']._options = None
  _JOBINSTANCESTATUS.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _JOBINSTANCESTATUS.fields_by_name['compute_instance_id']._options = None
  _JOBINSTANCESTATUS.fields_by_name['compute_instance_id']._serialized_options = b'\342J\021\n\017computeinstance'
  _JOBINSTANCESTATUS.fields_by_name['compute_instance_state']._options = None
  _JOBINSTANCESTATUS.fields_by_name['compute_instance_state']._serialized_options = b'\272H\003\310\001\001'
  _globals['_JOB']._serialized_start=225
  _globals['_JOB']._serialized_end=408
  _globals['_JOBSPEC']._serialized_start=411
  _globals['_JOBSPEC']._serialized_end=2130
  _globals['_JOBSPEC_ENVIRONMENTVARIABLE']._serialized_start=1278
  _globals['_JOBSPEC_ENVIRONMENTVARIABLE']._serialized_end=1354
  _globals['_JOBSPEC_PORT']._serialized_start=1357
  _globals['_JOBSPEC_PORT']._serialized_end=1596
  _globals['_JOBSPEC_PORT_PROTOCOL']._serialized_start=1532
  _globals['_JOBSPEC_PORT_PROTOCOL']._serialized_end=1596
  _globals['_JOBSPEC_VOLUMEMOUNT']._serialized_start=1599
  _globals['_JOBSPEC_VOLUMEMOUNT']._serialized_end=1876
  _globals['_JOBSPEC_VOLUMEMOUNT_MODE']._serialized_start=1817
  _globals['_JOBSPEC_VOLUMEMOUNT_MODE']._serialized_end=1876
  _globals['_JOBSPEC_DISKSPEC']._serialized_start=1878
  _globals['_JOBSPEC_DISKSPEC']._serialized_end=1985
  _globals['_JOBSPEC_REGISTRYCREDENTIALS']._serialized_start=1988
  _globals['_JOBSPEC_REGISTRYCREDENTIALS']._serialized_end=2130
  _globals['_JOBSTATUS']._serialized_start=2133
  _globals['_JOBSTATUS']._serialized_end=2577
  _globals['_JOBSTATUS_STATE']._serialized_start=2419
  _globals['_JOBSTATUS_STATE']._serialized_end=2577
  _globals['_JOBSTATEDETAILS']._serialized_start=2579
  _globals['_JOBSTATEDETAILS']._serialized_end=2650
  _globals['_JOBINSTANCESTATUS']._serialized_start=2653
  _globals['_JOBINSTANCESTATUS']._serialized_end=3159
  _globals['_JOBINSTANCESTATUS_STATE']._serialized_start=2985
  _globals['_JOBINSTANCESTATUS_STATE']._serialized_end=3159
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.capacity.v1 import resource_affinity_pb2 as _resource_affinity_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CapacityIntervalSpec(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CapacityIntervalStatus(_message.Message):
    __slots__ = ["container_id", "region", "resource_affinity", "service", "quantity", "start_time", "end_time", "state", "reconciling"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[CapacityIntervalStatus.State]
        STATE_SCHEDULED: _ClassVar[CapacityIntervalStatus.State]
        STATE_ACTIVE: _ClassVar[CapacityIntervalStatus.State]
        STATE_EXPIRED: _ClassVar[CapacityIntervalStatus.State]
    STATE_UNSPECIFIED: CapacityIntervalStatus.State
    STATE_SCHEDULED: CapacityIntervalStatus.State
    STATE_ACTIVE: CapacityIntervalStatus.State
    STATE_EXPIRED: CapacityIntervalStatus.State
    CONTAINER_ID_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_AFFINITY_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    RECONCILING_FIELD_NUMBER: _ClassVar[int]
    container_id: str
    region: str
    resource_affinity: _resource_affinity_pb2.ResourceAffinity
    service: str
    quantity: int
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    state: CapacityIntervalStatus.State
    reconciling: bool
    def __init__(self, container_id: _Optional[str] = ..., region: _Optional[str] = ..., resource_affinity: _Optional[_Union[_resource_affinity_pb2.ResourceAffinity, _Mapping]] = ..., service: _Optional[str] = ..., quantity: _Optional[int] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[CapacityIntervalStatus.State, str]] = ..., reconciling: bool = ...) -> None: ...

class CapacityInterval(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: CapacityIntervalSpec
    status: CapacityIntervalStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[CapacityIntervalSpec, _Mapping]] = ..., status: _Optional[_Union[CapacityIntervalStatus, _Mapping]] = ...) -> None: ...
